@@ -31,6 +31,10 @@ class Deployer:
         """
         self.__config = configuration
 
+        for s in {'action', 'folder'}:
+            if s not in self.__config:
+                self.__config[s] = {}
+
     def __run(self, bash_string):
         """
         Funzione che esegue i comandi specificati in bash_string e ritorna il loro output
